@@ -43,8 +43,9 @@ class _PropertyMixin(object):
     """Abstract mixin for cloud storage classes with associated properties.
 
     Non-abstract subclasses should implement:
-      - client
       - path
+      - client
+      - user_project
 
     :type name: str
     :param name: The name of the object. Bucket names must start and end with a
@@ -86,6 +87,26 @@ class _PropertyMixin(object):
             client = self.client
         return client
 
+    def _encryption_headers(self):
+        """Return any encryption headers needed to fetch the object.
+
+        .. note::
+           Defined here because :meth:`reload` calls it, but this method is
+           really only relevant for :class:`~google.cloud.storage.blob.Blob`.
+
+        :rtype: dict
+        :returns: a mapping of encryption-related headers.
+        """
+        return {}
+
+    @property
+    def _query_params(self):
+        """Default query parameters."""
+        params = {}
+        if self.user_project is not None:
+            params["userProject"] = self.user_project
+        return params
+
     def reload(self, client=None):
         """Reload properties from Cloud Storage.
 
@@ -97,13 +118,16 @@ class _PropertyMixin(object):
                        ``client`` stored on the current object.
         """
         client = self._require_client(client)
+        query_params = self._query_params
         # Pass only '?projection=noAcl' here because 'acl' and related
         # are handled via custom endpoints.
-        query_params = {"projection": "noAcl"}
-        if self.user_project is not None:
-            query_params["userProject"] = self.user_project
+        query_params["projection"] = "noAcl"
         api_response = client._connection.api_request(
-            method="GET", path=self.path, query_params=query_params, _target_object=self
+            method="GET",
+            path=self.path,
+            query_params=query_params,
+            headers=self._encryption_headers(),
+            _target_object=self,
         )
         self._set_properties(api_response)
 
@@ -148,11 +172,10 @@ class _PropertyMixin(object):
                        ``client`` stored on the current object.
         """
         client = self._require_client(client)
+        query_params = self._query_params
         # Pass '?projection=full' here because 'PATCH' documented not
         # to work properly w/ 'noAcl'.
-        query_params = {"projection": "full"}
-        if self.user_project is not None:
-            query_params["userProject"] = self.user_project
+        query_params["projection"] = "full"
         update_properties = {key: self._properties[key] for key in self._changes}
 
         # Make the API call.
@@ -178,9 +201,8 @@ class _PropertyMixin(object):
                        ``client`` stored on the current object.
         """
         client = self._require_client(client)
-        query_params = {"projection": "full"}
-        if self.user_project is not None:
-            query_params["userProject"] = self.user_project
+        query_params = self._query_params
+        query_params["projection"] = "full"
         api_response = client._connection.api_request(
             method="PUT",
             path=self.path,
